// Adafruit IO IFTTT Example - Gmailbox
// Tutorial Link: https://learn.adafruit.com/gmailbox
//
// Adafruit invests time and resources providing this open source code.
// Please support Adafruit and open source hardware by purchasing
// products from Adafruit!
//
// Written by Brent Rubell for Adafruit Industries
// Copyright (c) 2018 Adafruit Industries
// Licensed under the MIT license.
//
// All text above must be included in any redistribution.

//MODIFIED BY LMJD14 TO CREATE LOCATION "CLOCK"

/************************** Configuration ***********************************/

// edit the config.h tab and enter your Adafruit IO credentials
// and any additional configuration needed for WiFi, cellular,
// or ethernet clients.
#include "config.h"

// Import Servo Libraries
#if defined(ARDUINO_ARCH_ESP32)
  // ESP32Servo Library (https://github.com/madhephaestus/ESP32Servo)
  // installation: library manager -> search -> "ESP32Servo"
  #include <ESP32Servo.h>
#else
  #include <Servo.h>
#endif

/************************ Example Starts Here *******************************/

// holds the current count value for our sketch

// pin used to control the servo
#define SERVO_PIN 2

// Angle in degrees of "home" position
#define HOME 65

// Angle in degrees of "work" position
#define WORK 110

// Angle in degrees of "travelling" position
#define TRAVELLING 30

// Angle in degrees of "parents" position
#define PARENTS 0

//Angle in degrees of "shopping" position
#define SHOPPING 145

// Angle in degrees of "dance" position
#define DANCE 180

// create an instance of the servo class
Servo servo;

// set up the 'locations' feed
AdafruitIO_Feed *locations = io.feed("FEED NAME GOES HERE");

void setup() {

  // start the serial connection
  Serial.begin(115200);

  // wait for serial monitor to open
  while(! Serial);

  Serial.println();
  Serial.println("Single Person Weasley Clock");

  // tell the servo class which pin we are using
  servo.attach(SERVO_PIN);

  // connect to io.adafruit.com
  Serial.println("Connecting to Adafruit IO");
  io.connect();

  // set up a message handler for the 'servo' feed.
  // the handleMessage function (defined below)
  // will be called whenever a message is
  // received from adafruit io.
  locations->onMessage(handleMessage);

  // wait for a connection
  while(io.status() < AIO_CONNECTED) {
    Serial.print(".");
    delay(500);
  }

  // we are connected
  Serial.println();
  Serial.println(io.statusText());

  // get current values from both feeds
  locations->get();

}

void loop() {

  // io.run(); is required for all sketches.
  // it should always be present at the top of your loop
  // function. it keeps the client connected to
  // io.adafruit.com, and processes any incoming data.
  io.run();

  
}

// this function is called whenever a 'locations' message
// is received from Adafruit IO. it was attached to
// the locations feed in the setup() function above.

void handleMessage(AdafruitIO_Data *data) {

  String commandStr = data->toString(); // store the incoming commands in a string

  // received message
  Serial.print("received <- ");
  Serial.println(commandStr);
  
  if(commandStr == "HOME"){
    servo.write(HOME);
  }else if (commandStr == "WORK") {
    servo.write(WORK);
  }else if (commandStr == "TRAVELLING") {
    servo.write(TRAVELLING);
  }else if (commandStr == "PARENTS"){
    servo.write(PARENTS);
  }else if (commandStr == "SHOPPING"){
    servo.write(SHOPPING);
  }else if(commandStr == "DANCE"){
    servo.write(DANCE);
  }else {
    servo.write(TRAVELLING);
  }
}
